@@ -13,7 +13,8 @@
 #
 #
 oa <-
-function(flag, var1, var2, pCO2f, pCO2s=1e6, S=35, T=25, P=0, Pt=0, Sit=0, k1k2='x', kf='x', ks="d", pHscale="T", plot=FALSE,  b="u74"){
+function(flag, var1, var2, pCO2f, pCO2s=1e6, S=35, T=25, P=0, Pt=0, Sit=0, k1k2='x', kf='x', ks="d", pHscale="T", plot=FALSE,  b="u74",
+        eos="eos80", long=1.e20, lat=1.e20){
 
 n <- max(length(var1), length(var2), length(pCO2f), length(pCO2s), length(S), length(T), length(P), length(Pt), length(Sit), length(k1k2), length(kf), length(pHscale), length(ks))
 if(length(flag)!=n){ flag <- rep(flag[1],n)}
@@ -32,6 +33,11 @@ if(length(ks)!=n){ ks <- rep(ks[1],n)}
 if(length(pHscale)!=n){pHscale <- rep(pHscale[1],n)}
 if(length(b)!=n){ b <- rep(b[1],n)}
 
+
+# Only two options for eos
+if (eos != "teos10" && eos != "eos80")
+    stop ("invalid parameter eos: ", eos)
+
 # if the concentrations of total silicate and total phosphate are NA
 # they are set at 0
 Sit[is.na(Sit)] <- 0
@@ -39,18 +45,18 @@ Pt[is.na(Pt)] <- 0
 
 # initial system
 # --------------
-SYSi <- carb(flag=flag, var1=var1, var2=var2, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b)
+SYSi <- carb(flag=flag, var1=var1, var2=var2, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b, eos=eos, long=long, lat=lat)
 
 # CO2 bubbling
 # -----------------------------
-SYSfCO2bubbling <- carb(flag=24, var1=pCO2f, var2=SYSi$ALK, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b)
+SYSfCO2bubbling <- carb(flag=24, var1=pCO2f, var2=SYSi$ALK, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b, eos=eos, long=long, lat=lat)
 
 
 # Seawater mixing
 # ---------------------------------
-SYSs <- carb(flag=24, var1=pCO2s, var2=SYSi$ALK, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b)
+SYSs <- carb(flag=24, var1=pCO2s, var2=SYSi$ALK, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b, eos=eos, long=long, lat=lat)
 
-SYSf <- carb(flag=24, var1=pCO2f, var2=SYSi$ALK, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b)
+SYSf <- carb(flag=24, var1=pCO2f, var2=SYSi$ALK, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b, eos=eos, long=long, lat=lat)
 
 DICi <- SYSi$DIC
 DICs <- SYSs$DIC
@@ -66,7 +72,7 @@ SYSfSWmixing <- SYSf
 # Addition of strong acid
 # -----------------------------------
 
-SYSfacid <- carb(flag=25, var1=pCO2f, var2=SYSi$DIC, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b)
+SYSfacid <- carb(flag=25, var1=pCO2f, var2=SYSi$DIC, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b, eos=eos, long=long, lat=lat)
 ALKf <- SYSfacid$ALK
 ALKi <- SYSi$ALK
 
@@ -78,7 +84,7 @@ hplus <- round(hplus, 8)
 
 # Addition of strong acid and carbonate
 # ------------------------------------------------------
-SYSfCarboAcid <- carb(flag=24, var1=pCO2f, var2=SYSi$ALK, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf,  ks=ks, pHscale=pHscale, b=b)
+SYSfCarboAcid <- carb(flag=24, var1=pCO2f, var2=SYSi$ALK, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf,  ks=ks, pHscale=pHscale, b=b, eos=eos, long=long, lat=lat)
 
 deltaDIC <- SYSfCarboAcid$DIC - SYSi$DIC
 
@@ -88,7 +94,7 @@ TAintCO3 <- TAint  ## we keep the value for the plot
 
 DICint <- SYSfCarboAcid$DIC
 
-SYSint <- carb(flag=15, var1=TAint, var2=DICint, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b)
+SYSint <- carb(flag=15, var1=TAint, var2=DICint, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b, eos=eos, long=long, lat=lat)
 
 deltaTA <- SYSf$ALK-SYSint$ALK
 
@@ -101,7 +107,7 @@ TAintHCO3 <- TAint  ## we keep the value for the plot
 
 DICint <- SYSfCarboAcid$DIC
 
-SYSint <- carb(flag=15, var1=TAint, var2=DICint, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b)
+SYSint <- carb(flag=15, var1=TAint, var2=DICint, S=S, T=T, P=P, Sit=Sit, Pt=Pt, k1k2=k1k2, kf=kf, ks=ks, pHscale=pHscale, b=b, eos=eos, long=long, lat=lat)
 
 deltaTA <- SYSf$ALK-SYSint$ALK
 
@@ -201,7 +207,7 @@ arrows(xb, yb, xb, ybb, col="orange", lty=2, lwd=2)
 alk <- seq(y1, y2,, 15)
 dic <- seq(x1, x2,, 15)
 z <- expand.grid(ALK=alk, DIC=dic)
-cp <- carb(flag=15, var1=z$ALK, var2=z$DIC, T=T[1], P=P[1], S=S[1], Pt=Pt[1], Sit=Sit[1], pHscale=pHscale[1], k1k2=k1k2[1], kf=kf[1])
+cp <- carb(flag=15, var1=z$ALK, var2=z$DIC, T=T[1], P=P[1], S=S[1], Pt=Pt[1], Sit=Sit[1], pHscale=pHscale[1], k1k2=k1k2[1], kf=kf[1], eos=eos, long=long, lat=lat)
 pCO2 <- cp$pCO2
 M <- tapply(pCO2, z, unique)
 contour(dic, alk, t(M),
